@@ -5,4 +5,7 @@ from .grid import Grid
 from .sep import StorageEndpoint, StorageConfig, StoragePool
 from .image import Image
 from .disk import Disk
-from .extnet import ExternalNetwork
\ No newline at end of file
+from .extnet import ExternalNetwork
+from .cluster import Cluster
+from .host import Host
+from .vm import VM
\ No newline at end of file
